@@ -1,4 +1,7 @@
 #!/usr/bin/perl -w
+
+eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
+    if 0; # not running under some shell
 use strict;
 
 use Config;
@@ -11,16 +14,17 @@ use Data::Dumper;
 use File::Basename;
 my $findbin;
 BEGIN { $findbin = dirname $0 }
-use lib File::Spec->catdir( $findbin, 'lib' );
-use lib File::Spec->catdir( $findbin, 'lib', 'inc' );
-use lib $findbin;
-use lib File::Spec->catdir( $findbin, 'inc' );
-use Test::Smoke::Util qw( do_pod2usage whereis );
-use Test::Smoke::SysInfo;
 
-# $Id: configsmoke.pl 1303 2012-03-16 13:22:14Z abeltje $
-use vars qw( $VERSION $conf );
-$VERSION = '0.072';
+use lib File::Spec->catdir($findbin, 'lib');
+use lib File::Spec->catdir($findbin, 'lib', 'inc');
+use lib $findbin;
+use lib File::Spec->catdir($findbin, 'inc');
+use Test::Smoke::SysInfo;
+use Test::Smoke::Util qw(do_pod2usage whereis);
+
+# $Id: configsmoke.pl 1363 2012-05-10 21:21:26Z abeltje $
+use vars qw($VERSION $conf);
+$VERSION = '0.080';
 
 use Getopt::Long;
 my %options = ( 
@@ -61,6 +65,8 @@ foreach my $opt (qw( config jcl log )) {
         $options{oldcfg} = 1;
         print "Using '$options{config}' for defaults.\n";
         $conf->{perl_version} eq '5.9.x' and $conf->{perl_version} = '5.11.x';
+        $conf->{perl_version} eq '5.11.x' and $conf->{perl_version} = '5.13.x';
+        $conf->{perl_version} eq '5.13.x' and $conf->{perl_version} = '5.15.x';
     }
 
     if ( $load_error || $options{default} ) {
@@ -120,13 +126,14 @@ Current options:
 sub is_win32() { $^O eq 'MSWin32' }
 sub is_vms()   { $^O eq 'VMS'     }
 
-my %config = ( perl_version => $conf->{perl_version} || '5.11.x' );
+my %config = ( perl_version => $conf->{perl_version} || '5.15.x' );
 
 my %mailers = get_avail_mailers();
 my @mailers = sort keys %mailers;
 my @syncers = get_avail_sync();
 my $syncmsg = join "\n", @{ { 
     rsync    => "\trsync - Use the rsync(1) program [preferred]",
+    git      => "\tgit - Use a git-repository.",
     ftp      => "\tftp - Use Net::FTP to sync from APC [!slow!]",
     copy     => "\tcopy - Use File::Copy to copy from a local directory",
     hardlink => "\thardlink - Copy from a local directory using link()",
@@ -139,90 +146,136 @@ my %vdirs = map {
     my $vdir = $_;
     is_vms and $vdir =~ tr/.//d;
     ( $_ => $vdir )
-} qw( 5.5.x 5.8.x 5.10.x ); # unsupported: 5.6.2
+} qw( 5.8.x 5.10.x 5.12.x 5.14.x 5.16.x );
 
 my %versions = (
-#    '5.5.x' => { source => 'public.activestate.com::perl-5.005xx',
-#                 server => 'public.activestate.com',
-#                 sdir   => '/pub/apc/perl-5.005xx-snap',
-#                 sfile  => '',
-#                 pdir   => '/pub/apc/perl-5.005xx-diffs',
-#                 cfg    => 'perl55x.cfg',
-#                 ddir   => File::Spec->catdir( cwd(), File::Spec->updir,
-#                                               "perl-$vdirs{'5.5.x'}" ),
-#                 text   => 'Perl 5.005 MAINT',
-#                 is56x  => 1},
+    '5.8.x' => {
+        source  => 'perl5.git.perl.org::perl-5.8.x',
+        server  => 'http://perl5.git.perl.org',
+        sdir    => '/perl.git/snapshot/refs/heads/',
+        sfile   => 'maint-5.8.tar.gz',
+        pdir    => '',
+        ddir    => File::Spec->catdir(
+            cwd(),
+            File::Spec->updir,
+            "perl-$vdirs{'5.8.x'}"
+        ),
+        ftphost => 'public.activestate.com',
+        ftpusr  => 'anonymous',
+        ftppwd  => 'smokers@perl.org',
+        ftpsdir => '/pub/apc/perl-5.8.x',
+        ftpcdir => '/pub/apc/perl-5.8.x-diffs',
 
-#    '5.6.2' => { source => 'public.activestate.com::perl-5.6.2',
-#                 server => 'public.activestate.com',
-#                 sdir   => '/pub/apc/perl-5.6.2-snap',
-#                 sfile  => 'perl-5.6.2-latest.tar.gz',
-#                 pdir   => '/pub/apc/perl-5.6.2-diffs',
-#                 ddir   => File::Spec->catdir( cwd(), File::Spec->updir,
-#                                               "perl-$vdirs{'5.6.2'}" ),
-#                 ftphost => 'public.activestate.com',
-#                 ftpusr  => 'anonymous',
-#                 ftppwd  => 'smokers@perl.org',
-#                 ftpsdir => '/pub/apc/perl-5.6.2',
-#                 ftpcdir => '/pub/apc/perl-5.6.2-diffs',
-#
-#                 text   => 'Perl 5.6.2 (final?)',
-#                 cfg    => 'perl562.cfg',
-#                 is56x  => 1 },
+        text    => 'Perl 5.8 MAINT',
+        cfg     => (
+            is_win32
+                ? 'w32current.cfg'
+                : is_vms ? 'vmsperl.cfg' : 'perlmaint.cfg'
+        ),
+        is56x   => 0,
+    },
 
-    '5.8.x' => { source =>  'perl5.git.perl.org::perl-5.8.x',
-                 server => 'public.activestate.com',
-                 sdir   => '/pub/apc/perl-5.8.x-snap',
-                 sfile  => 'perl-5.8.x-latest.tar.gz',
-                 pdir   => '/pub/apc/perl-5.8.x-diffs',
-                 ddir   => File::Spec->catdir( cwd(), File::Spec->updir,
-                                               "perl-$vdirs{'5.8.x'}" ),
-                 ftphost => 'public.activestate.com',
-                 ftpusr  => 'anonymous',
-                 ftppwd  => 'smokers@perl.org',
-                 ftpsdir => '/pub/apc/perl-5.8.x',
-                 ftpcdir => '/pub/apc/perl-5.8.x-diffs',
+    '5.10.x' => {
+        source  => 'perl5.git.perl.org::perl-5.10.x',
+        server  => 'http://perl5.git.perl.org',
+        sdir    => '/perl.git/snapshot/refs/heads/',
+        sfile   => 'maint-5.10.tar.gz',
+        pdir    => '',
+        ddir    => File::Spec->catdir(
+            cwd(),
+            File::Spec->updir,
+            "perl-$vdirs{'5.10.x'}"
+        ),
+        ftphost => 'public.activestate.com',
+        ftpusr  => 'anonymous',
+        ftppwd  => 'smokers@perl.org',
+        ftpsdir => '/pub/apc/perl-5.10.x',
+        ftpcdir => '/pub/apc/perl-5.10.x-diffs',
 
-                 text   => 'Perl 5.8 MAINT',
-                 cfg    => ( is_win32 ? 'w32current.cfg'
-                           : is_vms ? 'vmsperl.cfg' : 'perl58x.cfg' ),
-                 is56x  => 0 },
+        text    => 'Perl 5.10 MAINT',
+        cfg     => (
+            is_win32
+                ? 'w32current.cfg'
+                : is_vms ? 'vmsperl.cfg' : 'perlmaint.cfg'
+        ),
+        is56x   => 0,
+    },
 
-    '5.10.x' => { source =>  'perl5.git.perl.org::perl-5.10.x',
-                  server => 'public.activestate.com',
-                  sdir   => '/pub/apc/perl-5.10.x-snap',
-                  sfile  => 'perl-5.10.x-latest.tar.gz',
-                  pdir   => '/pub/apc/perl-5.10.x-diffs',
-                  ddir   => File::Spec->catdir( cwd(), File::Spec->updir,
-                                                "perl-$vdirs{'5.10.x'}" ),
-                  ftphost => 'public.activestate.com',
-                  ftpusr  => 'anonymous',
-                  ftppwd  => 'smokers@perl.org',
-                  ftpsdir => '/pub/apc/perl-5.10.x',
-                  ftpcdir => '/pub/apc/perl-5.10.x-diffs',
- 
-                  text   => 'Perl 5.10 MAINT',
-                  cfg    => ( is_win32 ? 'w32current.cfg'
-                            : is_vms ? 'vmsperl.cfg' : 'perl510x.cfg' ),
-                  is56x  => 0 },
+    '5.12.x' => {
+        source  => 'perl5.git.perl.org::perl-5.12.x',
+        server  => 'http://perl5.git.perl.org',
+        sdir    => '/perl.git/snapshot/refs/heads/',
+        sfile   => 'maint-5.12.tar.gz',
+        pdir    => '/pub/apc/perl-current-diffs',
+        ddir    => File::Spec->catdir(
+            cwd(),
+            File::Spec->updir,
+            'perl-current'
+        ),
+        ftphost => 'public.activestate.com',
+        ftpusr  => 'anonymous',
+        ftppwd  => 'smokers@perl.org',
+        ftpsdir => '/pub/apc/perl-current',
+        ftpcdir => '/pub/apc/perl-current-diffs',
 
-    '5.11.x' => { source => 'perl5.git.perl.org::perl-current',
-                  server => 'public.activestate.com',
-                  sdir   => '/pub/apc/perl-current-snap',
-                  sfile  => 'perl-current-latest.tar.gz',
-                  pdir   => '/pub/apc/perl-current-diffs',
-                  ddir   => File::Spec->catdir( cwd(), File::Spec->updir,
-                                                'perl-current' ),
-                  ftphost => 'public.activestate.com',
-                  ftpusr  => 'anonymous',
-                  ftppwd  => 'smokers@perl.org',
-                  ftpsdir => '/pub/apc/perl-current',
-                  ftpcdir => '/pub/apc/perl-current-diffs',
- 
-                  text   => 'Perl 5.12 to-be',
-                  cfg    => ( is_win32 ? 'w32current.cfg'
-                            : is_vms ? 'vmsperl.cfg' : 'perlcurrent.cfg' ),
-                  is56x  => 0 },
+        text    => 'Perl 5.12 maint',
+        cfg     => (
+            is_win32
+                ? 'w32current.cfg'
+                : is_vms ? 'vmsperl.cfg' : 'perlmaint.cfg'
+        ),
+        is56x   => 0,
+    },
+    '5.14.x' => {
+        source  => 'perl5.git.perl.org::perl-5.14.x',
+        server  => 'http://perl5.git.perl.org',
+        sdir    => '/perl.git/snapshot/refs/heads/',
+        sfile   => 'maint-5.14.tar.gz',
+        pdir    => '/pub/apc/perl-current-diffs',
+        ddir    => File::Spec->catdir(
+            cwd(),
+            File::Spec->updir,
+            'perl-current'
+        ),
+        ftphost => 'public.activestate.com',
+        ftpusr  => 'anonymous',
+        ftppwd  => 'smokers@perl.org',
+        ftpsdir => '/pub/apc/perl-current',
+        ftpcdir => '/pub/apc/perl-current-diffs',
+
+        text    => 'Perl 5.14 maint',
+        cfg     => (
+            is_win32
+                ? 'w32current.cfg'
+                : is_vms ? 'vmsperl.cfg' : 'perlmaint.cfg'
+        ),
+        is56x   => 0,
+    },
+    '5.15.x' => {
+        source  => 'perl5.git.perl.org::perl-current',
+        server  => 'http://perl5.git.perl.org',
+        sdir    => '/perl.git/snapshot/',
+        sfile   => '',
+        pdir    => '/pub/apc/perl-current-diffs',
+        ddir    => File::Spec->catdir(
+            cwd(),
+            File::Spec->updir,
+            'perl-current'
+        ),
+        ftphost => 'public.activestate.com',
+        ftpusr  => 'anonymous',
+        ftppwd  => 'smokers@perl.org',
+        ftpsdir => '/pub/apc/perl-current',
+        ftpcdir => '/pub/apc/perl-current-diffs',
+
+        text    => 'Perl 5.16 to-be',
+        cfg     => (
+            is_win32
+                ? 'w32current.cfg'
+                : is_vms ? 'vmsperl.cfg' : 'perlcurrent.cfg'
+        ),
+        is56x   => 0,
+    },
 );
 my @pversions = sort {
     _perl_numeric_version( $a ) <=> _perl_numeric_version( $b )
@@ -349,13 +402,31 @@ my %opt = (
         dft => '/pub/languages/perl/snap',
     },
     sfile => {
-        msg => "Which file should be FTPed?
-\tLeave empty to automatically find newest.
-\tMandatory for HTTP! (see also --snapshot switch in perlsmoke.pl)",
+        msg => "Which file should be downloaded?
+\tLeave empty to automatically find newest.",
         alt => [ ],
         dft => '',
     },
 
+    gitbin => {
+        msg => "Which git binary do you want to use.",
+        alt => [ ],
+        dft => whereis('git'),
+    },
+    gitorigin => {
+        msg => "Git main repository?",
+        alt => [ ],
+        dft => 'git://perl5.git.perl.org/perl.git',
+    },
+    gitdir => {
+        msg => "Directory for the local git repository?",
+        alt => [ ],
+        dft => File::Spec->catdir(
+            File::Spec->rel2abs(File::Spec->updir),
+            'git-perl'
+        ),
+    },
+
     tar => {
         msg => "How should the snapshots be extracted?
 Examples:$untarmsg",
@@ -364,7 +435,7 @@ Examples:$untarmsg",
     },
 
     snapext => {
-        msg => 'What type of snapshots should be FTPed?',
+        msg => 'What type of snapshots should be downloaded?',
         alt => [qw( tgz tbz )],
         dft => 'tgz',
     },
@@ -508,14 +579,34 @@ EOT
         dft => '',
     },
 
+    # Test::Smoke::Gateway database
+    smokedb_url => {
+        msg => <<EOT,
+Send smoke results to the SmokeDB? (url)
+\t(Leave empty for no.)
+EOT
+        alt => [ ],
+        dft => 'http://perl5.test-smoke.org/report',
+    },
+    send_log => {
+        msg => 'Do you want to send the logfile with the report?',
+        alt => [qw( always on_fail never )],
+        dft => 'on_fail',
+    },
+    send_out => {
+        msg => 'Do you want to send the outfile with the report?',
+        alt => [qw( always on_fail never )],
+        dft => 'never',
+    },
+
     # mail stuff
     mail => {
-        msg => "Would you like your reports send by e-mail?",
+        msg => "Would you like to email your reports?",
         alt => [qw( N y )],
         dft => 'n',
     },
     mail_type => {
-        msg => 'Which mail facility should be used?',
+        msg => 'Which send facility should be used?',
         alt => [ @mailers ],
         dft => $mailers[0],
         nocase => 1,
@@ -1000,10 +1091,23 @@ SYNCER: {
         last SYNCER;
     };
 
+    /^git$/ && do {
+        $arg = 'gitbin';
+        $config{$arg} = prompt($arg);
+
+        $arg = 'gitorigin';
+        $config{$arg} = prompt($arg);
+
+        $arg = 'gitdir';
+        $config{$arg} = prompt_dir($arg);
+
+        last SYNCER;
+    };
+
     /^ftp$/  && do {
         for $arg (qw( ftphost ftpusr ftpsdir ftpcdir )) {
             $config{ $arg } = prompt( $arg );
-	}
+        }
         $config{ftppwd} = $conf->{ftppwd} || $opt{ftppwd}{dft};
 
         last SYNCER;
@@ -1036,8 +1140,8 @@ SYNCER: {
                 $opt{cleanup}->{msg} .= " 2(patches) 3(both)";
                 $opt{cleanup}->{alt}  = [0, 1, 2, 3];
             }
-	} else {
-	    $config{ $arg } = 0;
+        } else {
+            $config{ $arg } = 0;
         }
         $arg = 'cleanup';
         $config{ $arg } = prompt( $arg );
@@ -1196,6 +1300,48 @@ $list
     $config{ $arg } = prompt( $arg );
 }
 
+=item smokedb_url [http://perl5.test-smoke.org]
+
+Instead of flooding a mailing list, reposts should be sent to the SmokeDB.
+The option to mail yourself a copy of the report still exists. The SmokeDB
+however offers a central point of view to the smoke results.
+
+=item send_log <always|on_fail|never> [on_fail]
+
+Please send in the smoke-logfile for failures.
+
+=item send_out <always|on_fail|never> [never]
+
+=cut
+
+$arg = 'smokedb_url';
+SMOKEDB: {
+    eval q{require JSON;};
+    my $has_json = !$@;
+    if ( !$has_json ) {
+        $config{ $arg } = "";
+        print "Could not find 'JSON', please install.\n";
+        last SMOKEDB;
+    }
+
+    eval q{require LWP::UserAgent;};
+    my $has_lwp_useragent = !$@;
+    if ( !$has_lwp_useragent ) {
+        $config{ $arg } = "";
+        print "Could not find 'LWP::UserAgent', please install.\n";
+        last SMOKEDB;
+    }
+
+    $config{ $arg } = prompt( $arg );
+    last SMOKEDB if !$config{ $arg };
+
+    $arg = 'send_log';
+    $config{ $arg } = prompt( $arg );
+
+    $arg = 'send_out';
+    $config{ $arg } = prompt( $arg );
+}
+
 =item mail
 
 C<{mail}> will set the new default for L<smokeperl.pl>
@@ -1233,7 +1379,7 @@ MAIL: {
         /^sendmail$/       && do {
             $arg = 'from';
             $config{ $arg } = prompt( $arg );
-	};
+        };
 
         /^sendemail$/       && do {
             $arg = 'from';
@@ -1247,7 +1393,7 @@ MAIL: {
 
             $arg = 'mpass';
             $config{ $arg } = prompt( $arg );
-	};
+        };
 
         /^(?:Mail::Sendmail|MIME::Lite)$/ && do {
             $arg = 'from';
@@ -1474,7 +1620,8 @@ If you want this then set the directory where you want the stored
 
 $arg = 'adir';
 ( my $pver_nodot = $config{perl_version} ) =~ tr/.//d;
-$opt{ $arg }->{dft} = File::Spec->catdir( 'logs', $pver_nodot );
+my $adirsuf = $options{'prefix'} || $pver_nodot;
+$opt{ $arg }->{dft} = File::Spec->catdir( 'logs', $adirsuf );
 $config{ $arg } = prompt_dir( $arg );
 $config{lfile} = File::Spec->rel2abs( $options{log}, cwd );
 
@@ -1582,7 +1729,7 @@ SCHEDULE: {
         }
         foreach ( @current_cron ) {
             s/^(?<!#)(\d+.+(?:$options{jcl}|smoke)\.sh)/#$1/;
-	}
+        }
 
         my $jcl = File::Spec->rel2abs( "$options{jcl}.sh" );
         $new_entry = schedule_entry( $jcl, $cron, $crontime );
@@ -1705,6 +1852,9 @@ sub sort_configkeys {
         qw( mail mail_type mserver muser mpass from to ccp5p_onfail
             swcc cc swbcc bcc ),
 
+        #SmokeDB
+        qw( smokedb_url send_log send_out ),
+
         # Archive reports and logfile
         qw( adir lfile ),
 
@@ -2047,7 +2197,7 @@ sub prompt_file {
         $file = File::Spec->rel2abs( $file ) unless !$file && $no_valid;
 
         print "'$file' does not exist: $!\n" and redo GETFILE
-	    unless -f $file || $no_valid;
+            unless -f $file || $no_valid;
 
         printf "Got[%s]\n", defined $file ? $file : 'undef';
         return $file;
@@ -2110,7 +2260,10 @@ sub get_avail_sync {
 
     unshift @synctype, 'ftp' if $has_ftp;
 
+    unshift @synctype, 'git' if whereis('git');
+
     unshift @synctype, 'rsync' if whereis( 'rsync' );
+
     return @synctype;
 }
 
@@ -2288,7 +2441,8 @@ sub default_buildcfg {
     -f $file_name and return 1;
 
     $pversion =~ tr/.//d;
-    $pversion eq '511x' and $pversion = 'current';
+    my $is_devel = $pversion =~ /^5\d+[13579]x$/;
+    $pversion = $is_devel ? 'current' : 'maint';
     my $basename = is_win32
         ? "w32current.cfg"
         : is_vms ? "vmsperl.cfg" : "perl${pversion}.cfg";
@@ -2331,7 +2485,7 @@ sub check_buildcfg {
     my $uname_s = Test::Smoke::SysInfo::tsuname( 's' );
     my( $os, $osver ) = split /\s+-\s+/, $uname_s;
     # May assume much too much about OS version number formats.
-    my( $osvermaj, $osvermin ) = ($osver =~ /^.+?(\d+)\D+(\d+)/);
+    my( $osvermaj, $osvermin ) = ($osver =~ /^\D*(\d+)\D+(\d+)/);
     $osver = sprintf "%s", $osvermaj || '?'; 
     defined $osvermin and $osver .= sprintf ".%03d", $osvermin;
 
@@ -2349,7 +2503,7 @@ sub check_buildcfg {
             push @no_option, qw( -Duselongdouble -Dusemorebits -Duse64bitall );
         };
 
-	$os =~ /linux/i && do {
+        $os =~ /linux/i && do {
             push @no_option, qw( -Duse64bitall );
         };
 
@@ -2442,7 +2596,7 @@ Schedule, logfile optional
 
 In case I forget to update the C<$VERSION>:
 
-    $Id: configsmoke.pl 1303 2012-03-16 13:22:14Z abeltje $
+    $Id: configsmoke.pl 1363 2012-05-10 21:21:26Z abeltje $
 
 =head1 COPYRIGHT
 
